@@ -1,6 +1,8 @@
 [+ autogen5 template +]
 [+INCLUDE (string-append "licenses/" (get "License") ".tpl") \+]
-/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
+[+INCLUDE (string-append "indent.tpl") \+]
+/* [+INVOKE EMACS-MODELINE MODE="C" \+] */
+[+INVOKE START-INDENT\+]
 /*
  * lib.h
  * Copyright (C) [+(shell "date +%Y")+] [+Author+] <[+Email+]>
@@ -9,3 +11,4 @@
  */
 
 int [+NameCLower+]_func (void);
+[+INVOKE END-INDENT\+]
